==> tracing-decision-springboot-addon-1.2.0.Final-sources.jar: org/kie/kogito/tracing/decision/SpringBootModelEventEmitter.java <==
/*
 *  Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.kie.kogito.tracing.decision;

import javax.annotation.PostConstruct;

import org.kie.internal.decision.DecisionModelResourcesProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Component;

@Component
public class SpringBootModelEventEmitter extends BaseModelEventEmitter {

    private final KafkaTemplate<String, String> template;
    private final String kafkaTopicName;

    @Autowired
    public SpringBootModelEventEmitter(final DecisionModelResourcesProvider decisionModelResourcesProvider,
                                       final KafkaTemplate<String, String> template,
                                       final @Value(value = "${kogito.addon.tracing.model.kafka.topic.name:kogito-tracing-model}") String kafkaTopicName) {
        super(decisionModelResourcesProvider);
        this.template = template;
        this.kafkaTopicName = kafkaTopicName;
    }

    @Override
    @PostConstruct
    public void publishDecisionModels() {
        super.publishDecisionModels();
    }

    @Override
    public void emit(final String payload) {
        template.send(kafkaTopicName, payload);
    }
}

==> tracing-decision-springboot-addon-1.3.0.Final-sources.jar: org/kie/kogito/tracing/decision/SpringBootModelEventEmitter.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.tracing.decision;

import javax.annotation.PostConstruct;

import org.kie.kogito.decision.DecisionModelResourcesProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Component;

@Component
public class SpringBootModelEventEmitter extends BaseModelEventEmitter {

    private final KafkaTemplate<String, String> template;
    private final String kafkaTopicName;

    @Autowired
    public SpringBootModelEventEmitter(final DecisionModelResourcesProvider decisionModelResourcesProvider,
                                       final KafkaTemplate<String, String> template,
                                       final @Value(value = "${kogito.addon.tracing.model.kafka.topic.name:kogito-tracing-model}") String kafkaTopicName) {
        super(decisionModelResourcesProvider);
        this.template = template;
        this.kafkaTopicName = kafkaTopicName;
    }

    @Override
    @PostConstruct
    public void publishDecisionModels() {
        super.publishDecisionModels();
    }

    @Override
    public void emit(final String payload) {
        template.send(kafkaTopicName, payload);
    }
}
